==> lesstif_0.50.orig.tar.gz: lesstif-0.50.orig/include/Xm/MainWP.h <==
/**
 *
 * $Id: MainWP.h,v 1.4 1996/01/08 06:27:46 toshok Exp $
 * 
 * Copyright (C) 1995 Free Software Foundation, Inc.
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

#ifndef XM_MAINW_P_H
#define XM_MAINW_P_H

#include <Xm/MainW.h>
#include <Xm/ScrolledWP.h>
#include <Xm/SeparatoG.h>

#ifdef __cplusplus
extern "C" {
#endif

#define DEFAULT_HEIGHT 20
#define DEFAULT_WIDTH 20

/* Define the main window instance part */
typedef struct {
    Dimension AreaWidth, AreaHeight;
    Dimension margin_width, margin_height;
    Widget CommandWindow;
    Widget MenuBar;
    Widget Message;
    unsigned char CommandLoc;

    /* private instance variables */
    Widget Sep1, Sep2, Sep3;
    Boolean ManagingSep;
    Boolean ShowSep;
} XmMainWindowPart;

/* Define the full instance record */
typedef struct _XmMainWindowRec {
    CorePart core;
    CompositePart composite;
    ConstraintPart constraint;
    XmManagerPart manager;
    XmScrolledWindowPart swindow;
    XmMainWindowPart mwindow;
} XmMainWindowRec;

/* Define class part structure */
typedef struct {
    XtPointer extension;
} XmMainWindowClassPart;

/* Defint the full class record */
typedef struct _XmMainWindowClassRec {
    CoreClassPart core_class;
    CompositeClassPart composite_class;
    ConstraintClassPart constraint_class;
    XmManagerClassPart manager_class;
    XmScrolledWindowClassPart scrolled_window_class;
    XmMainWindowClassPart main_window_class;
} XmMainWindowClassRec;

extern XmMainWindowClassRec xmMainWindowClassRec;

#define MW_AreaWidth(w) \
    (((XmMainWindowWidget)w)->mwindow.AreaWidth)

#define MW_AreaHeight(w) \
    (((XmMainWindowWidget)w)->mwindow.AreaHeight)

#define MW_MarginWidth(w) \
    (((XmMainWindowWidget)w)->mwindow.margin_width)

#define MW_MarginHeight(w) \
    (((XmMainWindowWidget)w)->mwindow.margin_height)

#define MW_CommandWindow(w) \
    (((XmMainWindowWidget)w)->mwindow.CommandWindow)

#define MW_MenuBar(w) \
    (((XmMainWindowWidget)w)->mwindow.MenuBar)

#define MW_MessageWindow(w) \
    (((XmMainWindowWidget)w)->mwindow.Message)

#define MW_CommandLoc(w) \
    (((XmMainWindowWidget)w)->mwindow.CommandLoc)

#define MW_Sep1(w) \
    (((XmMainWindowWidget)w)->mwindow.Sep1)

#define MW_Sep2(w) \
    (((XmMainWindowWidget)w)->mwindow.Sep2)

#define MW_Sep3(w) \
    (((XmMainWindowWidget)w)->mwindow.Sep3)

#define MW_ShowSep(w) \
    (((XmMainWindowWidget)w)->mwindow.ShowSep)

#ifdef __cplusplus
};
#endif

#endif /* XM_MAINW_P_H */

==> lesstif_0.76.orig.tar.gz: lesstif-0.76.orig/include/Xm/MainWP.h <==
/**
 *
 * $Id: MainWP.h,v 1.4 1996/08/29 00:06:28 miers Exp $
 * 
 * Copyright (C) 1995 Free Software Foundation, Inc.
 *
 * This file is part of the GNU LessTif Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 **/

#ifndef XM_MAINW_P_H
#define XM_MAINW_P_H

#include <Xm/MainW.h>
#include <Xm/ScrolledWP.h>
#include <Xm/SeparatoG.h>

#ifdef __cplusplus
extern "C" {
#endif

/* Define the main window instance part */
typedef struct {
    Dimension AreaWidth, AreaHeight;
    Dimension margin_width, margin_height;
    Widget CommandWindow;
    Widget MenuBar;
    Widget Message;
    unsigned char CommandLoc;

    /* private instance variables */
    XmSeparatorGadget Sep1, Sep2, Sep3;
    Boolean ManagingSep;
    Boolean ShowSep;
} XmMainWindowPart;

/* Define the full instance record */
typedef struct _XmMainWindowRec {
    CorePart core;
    CompositePart composite;
    ConstraintPart constraint;
    XmManagerPart manager;
    XmScrolledWindowPart swindow;
    XmMainWindowPart mwindow;
} XmMainWindowRec;

/* Define class part structure */
typedef struct {
    XtPointer extension;
} XmMainWindowClassPart;

/* Defint the full class record */
typedef struct _XmMainWindowClassRec {
    CoreClassPart core_class;
    CompositeClassPart composite_class;
    ConstraintClassPart constraint_class;
    XmManagerClassPart manager_class;
    XmScrolledWindowClassPart scrolled_window_class;
    XmMainWindowClassPart main_window_class;
} XmMainWindowClassRec;

extern XmMainWindowClassRec xmMainWindowClassRec;

#ifdef __cplusplus
}
#endif

#endif /* XM_MAINW_P_H */
